@@ -177,6 +177,39 @@ class BaseDialog(QtGui.QDialog):
         filenames = glob(prefix+'*'+extension)
         return sorted(filenames,key=natural_sort)
 
+    def parameter_grid(self, parameters):
+        """
+        Returns a Qt grid layout with one row for each parameter.
+        
+        'parameters' should be a list of parameters, each one of which is a 
+        tuple containing the parameter label and its default value. If the 
+        default value is a list or tuple, a QComboBox will be used instead of
+        a QLineEdit to select the parameter.
+        """
+        grid = QtGui.QGridLayout()
+        grid.setSpacing(10)
+        self.grid_row = {}
+        row = 0
+        for parameter in parameters:
+            label, value = parameter
+            self.grid_row[label].label = QtGui.QLabel(label)
+            if isinstance(value, list) or isinstance(value, tuple):
+                self.grid_row[label].box = QtGui.QComboBox()
+                self.grid_row[label].box.setSizeAdjustPolicy(QtGui.QComboBox.AdjustToContents)
+                for v in value:
+                    self.grid_row[label].box.addItem(str(v))
+            else:
+                self.grid_row[label].box = QtGui.QLineEdit()
+                if value is not None:
+                    self.grid_row[label].box.setText(str(value))
+            grid.addWidget(self.grid_row[label].label, row, 0)
+            grid.addWidget(self.grid_row[label].box, row, 1)
+            row += 1
+        return grid 
+
+    def get_parameter(self, label):
+        return self.grid_row[label].box.text()
+ 
     def read_parameter(self, root, path):
         """
         Read the value from the NeXus path.
@@ -1403,6 +1436,7 @@ class FitDialog(BaseDialog):
     def closeEvent(self, event):
         event.accept()
 
+
 class LogDialog(BaseDialog):
     """Dialog to display a NeXpy log filt"""
  
@@ -1443,12 +1477,14 @@ class LogDialog(BaseDialog):
 
     def show_log(self):
         f = open(self.file_name, 'r')
-        text = self.ansi_re.sub('', f.read())
+        try:
+            from ansi2html import Ansi2HTMLConverter
+            conv = Ansi2HTMLConverter(dark_bg=False, inline=True)
+            text = conv.convert(''.join(f.readlines()))
+            self.text_box.appendHtml(text)
+        except ImportError:
+            self.text_box.setPlainText(self.ansi_re.sub('', f.read()))
         f.close()
-        self.text_box.setPlainText(text)
         self.text_box.verticalScrollBar().setValue(
             self.text_box.verticalScrollBar().maximum())
         self.setWindowTitle("Log File: %s" % self.file_name)
-
-
-
